#!/usr/bin/env python
#-*- coding:utf-8 -*-

__doc__ = "The shell data type into Python."
__date__ = '2016-03-28'
__author__ = "Tao Chengwei <staugur@saintic.com>"
__version__ = '0.3.1'

class S2P:

    __doc__ = """The shell data type into Python.
    From the configuration file into the shell array variable, this variable will be interpreted as a python array and returns the object.
    1. Need the module `configobj`;
    2. `section` in the configure file;
    3. Instantiation `S2P`, use the `ToList` function and `ToDict` function.
    """

    def __init__(self, f, section):
        "Parse the configuration file, set the f and section variale."
        import os
        if not os.path.isfile(f):
            raise IOError('%s not a file.' % f)
        if not section:
            raise
        self.f = f
        self.section = section

    def ShellConfigRead(self):
       "The analytical file in an array or a field dictionary."
       try:
            from configobj import ConfigObj
            return ConfigObj(self.f)[self.section]
       except ImportError:
            raise ImportError('Import module configobj failed, maybe you need to install it. (pip install configobj)')
       except Exception:
            raise

    def ToList(self, var):
         """
         This method will convert shell array into python array.
         The `var` should be from file, environ, etc.
         """
         try:
             r=self.ShellConfigRead()[var].replace('(', '').replace(')', '').replace('\"', '').replace('\'', '').split()
         except Exception, e:
             return e
         _L=[]
         for i in r:
             _L.append(i)
         return _L

    def ToDict(self, var):
        """
        This method will convert shell dict into python dict. The `var` should be from file, environ, etc.
        """
        try:
            _r=self.ShellConfigRead().get(var)
            _r=str(_r).replace('(', '').replace(')', '').replace('\"', '').replace('\'', '').replace('[', '').replace(']', '').replace('{', '').replace('}', '').replace(',','').split()
        except Exception, e:
            return e
        _D={}
        for i in _r:
            k=i.split('=')[0]
            v=i.split('=')[1]
            _D[k]=v
        return _D

if __name__ == '__main__':
    import sys
    def testLIST():
        if len(sys.argv) > 1:
            var=sys.argv[1]
        else:
            var="array"
        r=S2P(f='example.conf', section='shell').ToList(var=var)
        print type(r),r
        for i in r:
            print type(i),i

    def testDICT():
        if len(sys.argv) > 1:
            var=sys.argv[1]
        else:
            var='dic'
        r=S2P(f='example.conf', section='test').ToDict(var=var)
        for k,v in r.iteritems():
            print "%-5s====> %s" %(k,v)

    """
    If you want to convert list, please use the `testLIST()`;
    If you want to convert dict, please use the `testDICT()`.
    """
